@@ -58,17 +58,17 @@ UpdateModel::~UpdateModel()
 
 QHash<int,QByteArray> UpdateModel::roleNames() const
 {
-    return QAbstractItemModel::roleNames().unite({
-        { Qt::CheckStateRole, "checked" },
-        { ResourceProgressRole, "resourceProgress" },
-        { ResourceStateRole, "resourceState" },
-        { ResourceRole, "resource" },
-        { SizeRole, "size" },
-        { SectionRole, "section" },
-        { ChangelogRole, "changelog" },
-        { InstalledVersionRole, "installedVersion" },
-        { AvailableVersionRole, "availableVersion" }
-    } );
+    auto ret = QAbstractItemModel::roleNames();
+    ret.insert(Qt::CheckStateRole, "checked");
+    ret.insert(ResourceProgressRole, "resourceProgress");
+    ret.insert(ResourceStateRole, "resourceState");
+    ret.insert(ResourceRole, "resource");
+    ret.insert(SizeRole, "size");
+    ret.insert(SectionRole, "section");
+    ret.insert(ChangelogRole, "changelog");
+    ret.insert(InstalledVersionRole, "installedVersion");
+    ret.insert(AvailableVersionRole, "availableVersion");
+    return ret;
 }
 
 void UpdateModel::setBackend(ResourcesUpdatesModel* updates)
@@ -318,7 +318,7 @@ UpdateItem * UpdateModel::itemFromResource(AbstractResource* res)
 
 QString UpdateModel::updateSize() const
 {
-    return KFormat().formatByteSize(m_updates->updateSize());
+    return m_updates ? KFormat().formatByteSize(m_updates->updateSize()) : QString();
 }
 
 QModelIndex UpdateModel::indexFromItem(UpdateItem* item) const
